==> jaysonic-3.1.1.tgz: package/lib/server/protocol/http.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _get(target, property, receiver) { if (typeof Reflect !== "undefined" && Reflect.get) { _get = Reflect.get; } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(receiver); } return desc.value; }; } return _get(target, property, receiver || target); }

function _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

var JsonRpcServerProtocol = require("./base");

var _require = require("../../util/constants"),
    errorToStatus = _require.errorToStatus;
/**
 * Creates instance of HttpServerProtocol
 * @extends JsonRpcServerProtocol
 *
 */


var HttpServerProtocol = /*#__PURE__*/function (_JsonRpcServerProtoco) {
  _inherits(HttpServerProtocol, _JsonRpcServerProtoco);

  var _super = _createSuper(HttpServerProtocol);

  /**
   * As well as all the params and properties in [JsonRpcServerProtocol]{@link JsonRpcServerProtocol}
   * the following properties are available.
   *
   * @property {class} response HTTP response object
   *
   */
  function HttpServerProtocol(factory, client, response, version, delimiter) {
    var _this;

    _classCallCheck(this, HttpServerProtocol);

    _this = _super.call(this, factory, client, version, delimiter);
    _this.response = response;
    return _this;
  }
  /**
   * Send message to the client. If a notification is passed, then
   * a 204 response code is sent.
   *
   * @param {string} message Stringified JSON-RPC message object
   * @param {boolean} notification Indicates if message is a notification
   */


  _createClass(HttpServerProtocol, [{
    key: "writeToClient",
    value: function writeToClient(message, notification) {
      var _this2 = this;

      if (notification) {
        this._setResponseHeader({
          response: this.response,
          notification: true
        });

        this.response.end();
        return;
      }

      var json = JSON.parse(message);
      var header = {
        response: this.response
      };

      if ("error" in json && json.error !== null) {
        header.errorCode = json.error.code;
      }

      this._setResponseHeader(header);

      this.response.write(message, function () {
        _this2.response.end();
      });
    }
    /**
     * Calls `emit` on factory with the event name being `message.method` and
     * the date being `message`. Responds to client.
     *
     * @param {string} message Stringified JSON-RPC message object
     */

  }, {
    key: "gotNotification",
    value: function gotNotification(message) {
      _get(_getPrototypeOf(HttpServerProtocol.prototype), "gotNotification", this).call(this, message.method, message);

      this.writeToClient(message, true);
    }
    /** @inheritdoc */

  }, {
    key: "clientConnected",
    value: function clientConnected() {
      var _this3 = this;

      this.client.on(this.event, function (data) {
        _this3.client.on("end", function () {
          _this3._validateData(data);
        });
      });
    }
    /**
     * Set response header and response code
     *
     * @param {object} options
     * @param {class} options.response Http response instance
     * @param {boolean} options.notification Inidicate if setting header for notification
     * @param {number} options.errorCode The JSON-RPC error code to lookup a corresponding status code for
     * @private
     */

  }, {
    key: "_setResponseHeader",
    value: function _setResponseHeader(_ref) {
      var response = _ref.response,
          errorCode = _ref.errorCode,
          notification = _ref.notification;
      var statusCode = 200;

      if (notification) {
        statusCode = 204;
      }

      var header = {
        "Content-Type": "application/json"
      };

      if (errorCode) {
        statusCode = errorToStatus[String(errorCode)];
      }

      response.writeHead(statusCode, header);
    }
  }]);

  return HttpServerProtocol;
}(JsonRpcServerProtocol);

module.exports = HttpServerProtocol;

==> jaysonic-3.3.1.tgz: package/lib/server/protocol/http.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _get(target, property, receiver) { if (typeof Reflect !== "undefined" && Reflect.get) { _get = Reflect.get; } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(receiver); } return desc.value; }; } return _get(target, property, receiver || target); }

function _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

var JsonRpcServerProtocol = require("./base");

var _require = require("../../util/constants"),
    errorToStatus = _require.errorToStatus;
/**
 * Creates instance of HttpServerProtocol
 * @extends JsonRpcServerProtocol
 *
 */


var HttpServerProtocol = /*#__PURE__*/function (_JsonRpcServerProtoco) {
  _inherits(HttpServerProtocol, _JsonRpcServerProtoco);

  var _super = _createSuper(HttpServerProtocol);

  /**
   * As well as all the params and properties in [JsonRpcServerProtocol]{@link JsonRpcServerProtocol}
   * the following properties are available.
   *
   * @property {class} response HTTP response object
   *
   */
  function HttpServerProtocol(factory, client, response, version, delimiter) {
    var _this;

    _classCallCheck(this, HttpServerProtocol);

    _this = _super.call(this, factory, client, version, delimiter);
    _this.response = response;
    return _this;
  }
  /**
   * Send message to the client. If a notification is passed, then
   * a 204 response code is sent.
   *
   * @param {string} message Stringified JSON-RPC message object
   * @param {boolean} notification Indicates if message is a notification
   */


  _createClass(HttpServerProtocol, [{
    key: "writeToClient",
    value: function writeToClient(message, notification) {
      var _this2 = this;

      if (notification) {
        this._setResponseHeader({
          response: this.response,
          notification: true
        });

        this.response.end();
        return;
      }

      var json = JSON.parse(message);
      var header = {
        response: this.response
      };

      if ("error" in json && json.error !== null) {
        header.errorCode = json.error.code;
      }

      this._setResponseHeader(header);

      this.response.write(message, function () {
        _this2.response.end();
      });
    }
    /**
     * Calls `emit` on factory with the event name being `message.method` and
     * the date being `message`. Responds to client.
     *
     * @param {string} message Stringified JSON-RPC message object
     */

  }, {
    key: "gotNotification",
    value: function gotNotification(message) {
      _get(_getPrototypeOf(HttpServerProtocol.prototype), "gotNotification", this).call(this, message.method, message);

      this.writeToClient(message, true);
    }
    /** @inheritdoc */

  }, {
    key: "clientConnected",
    value: function clientConnected() {
      var _this3 = this;

      this.client.on(this.event, function (data) {
        _this3.client.on("end", function () {
          _this3._validateData(data);
        });
      });
    }
    /**
     * Set response header and response code
     *
     * @param {object} options
     * @param {class} options.response Http response instance
     * @param {boolean} options.notification Inidicate if setting header for notification
     * @param {number} options.errorCode The JSON-RPC error code to lookup a corresponding status code for
     * @private
     */

  }, {
    key: "_setResponseHeader",
    value: function _setResponseHeader(_ref) {
      var response = _ref.response,
          errorCode = _ref.errorCode,
          notification = _ref.notification;
      var statusCode = 200;

      if (notification) {
        statusCode = 204;
      }

      var header = {
        "Content-Type": "application/json"
      };

      if (errorCode) {
        statusCode = errorToStatus[String(errorCode)];
      }

      response.writeHead(statusCode, header);
    }
  }]);

  return HttpServerProtocol;
}(JsonRpcServerProtocol);

module.exports = HttpServerProtocol;
